@@ -27,23 +27,29 @@ typedef struct filetype filetype;
 struct filetype {
         char *end;
         char *type;
-        void (* f)(int, char *, char *, char *, char *, char *);
+        void (* f)(int, char *, char *, char *, char *, char *, char *,
+		char *);
 };
 
 filetype *gettype(char *filename);
-void *gmallocz(int l, int d);
-char *gstrdup(char *str);
+void *xcalloc(size_t, size_t);
+void *xmalloc(size_t);
+void *xrealloc(void *, size_t);
+char *xstrdup(const char *str);
+int xsendfile(int, int);
 Indexs *scanfile(char *fname);
 Elems *getadv(char *str);
+int printelem(int fd, Elems *el, char *addr, char *port);
+void addindexs(Indexs *idx, Elems *el);
 void addelem(Elems *e, char *s);
 void freeindex(Indexs *i);
 void freeelem(Elems *e);
-char *readln(int fd);
-void tprintf(int fd, char *fmt, ...);
 int initlogging(char *logf);
 void stoplogging(int fd);
 char *smprintf(char *fmt, ...);
 char *reverselookup(char *host);
+void setcgienviron(char *file, char *path, char *port, char *base,
+		char *args, char *sear, char *ohost, char *chost);
 
 #endif
 
